==> hestia_earth_aggregation-0.12.0-py3-none-any.whl: tests/aggregation/models/test_terms.py <==
from unittest.mock import patch
import json

from tests.utils import (
    SOURCE, fixtures_path, fake_download, fake_grouped_cycles, fake_grouped_impacts, start_year, end_year,
    fake_aggregated_version
)
from hestia_earth.aggregation.utils import _group_by_product
from hestia_earth.aggregation.models.terms import aggregate

class_path = 'hestia_earth.aggregation.models.terms'


@patch('hestia_earth.aggregation.cycle.quality_score.get_emissions_system_boundary', return_value=[])
@patch('hestia_earth.aggregation.cycle.emission._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.input._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.practice.download_hestia', side_effect=fake_download)
@patch('hestia_earth.aggregation.cycle.product._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.utils._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.utils._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.measurement._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.site._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.site._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.queries.download_hestia', side_effect=fake_download)
def test_aggregate_cycle(*args):
    from hestia_earth.aggregation.cycle.utils import (
        AGGREGATION_KEYS, _update_cycle, _format_terms_results
    )
    from hestia_earth.aggregation.cycle.quality_score import calculate_score

    with open(f"{fixtures_path}/cycle/terms/aggregated.jsonld", encoding='utf-8') as f:
        expected = json.load(f)

    cycles = fake_grouped_cycles()
    results = aggregate(AGGREGATION_KEYS, cycles)
    results = list(map(_format_terms_results, results))
    results = list(map(_update_cycle(None, start_year, end_year, SOURCE), results))
    results = list(map(calculate_score, results))
    assert results == expected


@patch('hestia_earth.aggregation.cycle.quality_score.get_emissions_system_boundary', return_value=[])
@patch('hestia_earth.aggregation.cycle.emission._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.input._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.practice.download_hestia', side_effect=fake_download)
@patch('hestia_earth.aggregation.cycle.product._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.utils._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.utils._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.measurement._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.site._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.site._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.queries.download_hestia', side_effect=fake_download)
def test_aggregate_cycle_relative(*args):
    from hestia_earth.aggregation.cycle.utils import (
        AGGREGATION_KEYS, _update_cycle, _format_terms_results, _format_for_grouping
    )
    from hestia_earth.aggregation.cycle.quality_score import calculate_score

    with open(f"{fixtures_path}/cycle/relative-unit.jsonld", encoding='utf-8') as f:
        cycles = json.load(f)
    with open(f"{fixtures_path}/cycle/terms/relative-unit-aggregated.jsonld", encoding='utf-8') as f:
        expected = json.load(f)

    cycles = _group_by_product({
        "@type": "Term",
        "name": "Meat, chicken (liveweight)",
        "termType": "animalProduct",
        "@id": "meatChickenLiveweight",
        "units": "kg liveweight"
    }, _format_for_grouping(cycles), AGGREGATION_KEYS)
    results = aggregate(AGGREGATION_KEYS, cycles)
    results = list(map(_format_terms_results, results))
    results = list(map(_update_cycle(None, start_year, end_year, SOURCE), results))
    results = list(map(calculate_score, results))
    assert results == expected


@patch('hestia_earth.aggregation.impact_assessment.indicator._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.impact_assessment.utils._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.impact_assessment.utils._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.impact_assessment.utils.node_exists', return_value=True)
@patch('hestia_earth.aggregation.impact_assessment.utils.download_hestia', return_value={})
@patch('hestia_earth.aggregation.utils.queries.download_hestia', side_effect=fake_download)
def test_aggregate_impact(*args):
    from hestia_earth.aggregation.impact_assessment.utils import (
        AGGREGATION_KEYS, _update_impact_assessment, _format_terms_results
    )

    with open(f"{fixtures_path}/impact-assessment/terms/aggregated.jsonld", encoding='utf-8') as f:
        expected = json.load(f)

    impacts = fake_grouped_impacts()
    results = aggregate(AGGREGATION_KEYS, impacts)
    results = list(map(_format_terms_results, results))
    results = list(map(_update_impact_assessment(None, start_year, end_year, SOURCE), results))
    assert results == expected

==> hestia_earth_aggregation-0.15.2-py3-none-any.whl: tests/aggregation/models/test_terms.py <==
from unittest.mock import patch
import json

from tests.utils import (
    SOURCE, fixtures_path, fake_download, fake_grouped_cycles, fake_grouped_impacts, start_year, end_year,
    fake_aggregated_version
)
from hestia_earth.aggregation.utils import _group_by_product
from hestia_earth.aggregation.models.terms import aggregate

class_path = 'hestia_earth.aggregation.models.terms'


@patch('hestia_earth.aggregation.cycle.quality_score.is_in_system_boundary', return_value=False)
@patch('hestia_earth.aggregation.cycle.emission.is_in_system_boundary', return_value=True)
@patch('hestia_earth.aggregation.cycle.emission._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.input._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.practice.download_hestia', side_effect=fake_download)
@patch('hestia_earth.aggregation.cycle.product._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.utils._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.utils._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.measurement._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.site._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.site._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.queries.download_hestia', side_effect=fake_download)
def test_aggregate_cycle(*args):
    from hestia_earth.aggregation.cycle.utils import (
        AGGREGATION_KEYS, _update_cycle, _format_terms_results
    )
    from hestia_earth.aggregation.cycle.quality_score import calculate_score

    with open(f"{fixtures_path}/cycle/terms/aggregated.jsonld", encoding='utf-8') as f:
        expected = json.load(f)

    cycles = fake_grouped_cycles()
    results = aggregate(AGGREGATION_KEYS, cycles)
    results = list(map(_format_terms_results, results))
    results = list(map(_update_cycle(None, start_year, end_year, SOURCE), results))
    results = list(map(calculate_score, results))
    assert results == expected


@patch('hestia_earth.aggregation.cycle.quality_score.is_in_system_boundary', return_value=False)
@patch('hestia_earth.aggregation.cycle.emission.is_in_system_boundary', return_value=True)
@patch('hestia_earth.aggregation.cycle.emission._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.input._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.practice.download_hestia', side_effect=fake_download)
@patch('hestia_earth.aggregation.cycle.product._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.utils._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.cycle.utils._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.measurement._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.site._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.site._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.utils.queries.download_hestia', side_effect=fake_download)
def test_aggregate_cycle_relative(*args):
    from hestia_earth.aggregation.cycle.utils import (
        AGGREGATION_KEYS, _update_cycle, _format_terms_results, _format_for_grouping
    )
    from hestia_earth.aggregation.cycle.quality_score import calculate_score

    with open(f"{fixtures_path}/cycle/relative-unit.jsonld", encoding='utf-8') as f:
        cycles = json.load(f)
    with open(f"{fixtures_path}/cycle/terms/relative-unit-aggregated.jsonld", encoding='utf-8') as f:
        expected = json.load(f)

    cycles = _group_by_product({
        "@type": "Term",
        "name": "Meat, chicken (liveweight)",
        "termType": "animalProduct",
        "@id": "meatChickenLiveweight",
        "units": "kg liveweight"
    }, _format_for_grouping(cycles), AGGREGATION_KEYS)
    results = aggregate(AGGREGATION_KEYS, cycles)
    results = list(map(_format_terms_results, results))
    results = list(map(_update_cycle(None, start_year, end_year, SOURCE), results))
    results = list(map(calculate_score, results))
    assert results == expected


@patch('hestia_earth.aggregation.impact_assessment.indicator._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.impact_assessment.utils._aggregated_version', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.impact_assessment.utils._aggregated_node', side_effect=fake_aggregated_version)
@patch('hestia_earth.aggregation.impact_assessment.utils.node_exists', return_value=True)
@patch('hestia_earth.aggregation.impact_assessment.utils.download_hestia', return_value={})
@patch('hestia_earth.aggregation.utils.queries.download_hestia', side_effect=fake_download)
def test_aggregate_impact(*args):
    from hestia_earth.aggregation.impact_assessment.utils import (
        AGGREGATION_KEYS, _update_impact_assessment, _format_terms_results
    )

    with open(f"{fixtures_path}/impact-assessment/terms/aggregated.jsonld", encoding='utf-8') as f:
        expected = json.load(f)

    impacts = fake_grouped_impacts()
    results = aggregate(AGGREGATION_KEYS, impacts)
    results = list(map(_format_terms_results, results))
    results = list(map(_update_impact_assessment(None, start_year, end_year, SOURCE), results))
    assert results == expected
